```
Usage: vcd gateway services service-certificate delete [OPTIONS] <gateway
                                                       name> certificate-id

Options:
  -h, --help  Show this message and exit.

```
